@@ -23,7 +23,7 @@ def encrypt(msg, key=None):
     if not key:
         return msg.encode('utf-8')
     else:
-        key = _pad_key(key)
+        key = _pad_key(key).encode('utf-8')
 
     msg = (msg + '$').encode('utf-8')
     padded_msg = msg.ljust((len(msg) // 16 + 1) * 16)
@@ -36,7 +36,7 @@ def decrypt(encoded, key=None):
     if not key:
         return encoded.decode('utf-8')
     else:
-        key = _pad_key(key)
+        key = _pad_key(key).encode('utf-8')
 
     cipher = AES.new(key, AES.MODE_ECB)
     decoded = base64.b64decode(encoded)
